import { DataGrid, GridColDef, GridRenderCellParams } from "@mui/x-data-grid";
import { carrierStore } from "@shared";
import { useEffect, useState } from "react";
import { observer } from "mobx-react-lite";
import { Eye, Pencil, Trash2 } from "lucide-react";
import { useNavigate } from "react-router-dom";
import { CreateButton, DeleteModal } from "@widgets";

export const CarrierListPage = observer(() => {
  const { carriers, getCarriers, deleteCarrier } = carrierStore;
  const navigate = useNavigate();
  const [isDeleteModalOpen, setIsDeleteModalOpen] = useState(false);
  const [rowId, setRowId] = useState<number | null>(null); // Lifted state

  useEffect(() => {
    getCarriers();
  }, []);

  const columns: GridColDef[] = [
    {
      field: "full_name",
      headerName: "Полное имя",

      width: 300,
    },
    {
      field: "short_name",
      headerName: "Короткое имя",
      width: 200,
    },
    {
      field: "city",
      headerName: "Город",
      flex: 1,
    },
    {
      field: "actions",
      headerName: "Действия",
      headerAlign: "center",
      width: 200,

      renderCell: (params: GridRenderCellParams) => {
        return (
          <div className="flex h-full gap-7 justify-center items-center">
            <button onClick={() => navigate(`/carrier/${params.row.id}/edit`)}>
              <Pencil size={20} className="text-blue-500" />
            </button>
            <button onClick={() => navigate(`/carrier/${params.row.id}`)}>
              <Eye size={20} className="text-green-500" />
            </button>
            <button
              onClick={() => {
                setIsDeleteModalOpen(true);
                setRowId(params.row.id);
              }}
            >
              <Trash2 size={20} className="text-red-500" />
            </button>
          </div>
        );
      },
    },
  ];

  const rows = carriers.data?.map((carrier) => ({
    id: carrier.id,
    full_name: carrier.full_name,
    short_name: carrier.short_name,
    city: carrier.city,
  }));

  return (
    <>
      <div className="w-full">
        <div className="flex justify-between items-center mb-10">
          <h1 className="text-2xl">Перевозчики</h1>
          <CreateButton label="Создать перевозчика" path="/carrier/create" />
        </div>
        <DataGrid
          rows={rows}
          columns={columns}
          hideFooterPagination
          hideFooter
        />
      </div>

      <DeleteModal
        open={isDeleteModalOpen}
        onDelete={async () => {
          if (rowId) {
            await deleteCarrier(rowId);
          }
          setIsDeleteModalOpen(false);
          setRowId(null);
        }}
        onCancel={() => {
          setIsDeleteModalOpen(false);
          setRowId(null);
        }}
      />
    </>
  );
});
