import { DataGrid, GridColDef, GridRenderCellParams } from "@mui/x-data-grid";
import { languageStore, MEDIA_TYPE_LABELS, mediaStore } from "@shared";
import { useEffect, useState } from "react";
import { observer } from "mobx-react-lite";
import { Eye, Trash2 } from "lucide-react";
import { useNavigate } from "react-router-dom";
import { CreateButton, DeleteModal, LanguageSwitcher } from "@widgets";

export const MediaListPage = observer(() => {
  const { media, getMedia, deleteMedia } = mediaStore;
  const navigate = useNavigate();
  const [isDeleteModalOpen, setIsDeleteModalOpen] = useState(false);
  const [rowId, setRowId] = useState<string | null>(null); // Lifted state
  const { language } = languageStore;

  useEffect(() => {
    getMedia();
  }, [language]);

  const columns: GridColDef[] = [
    {
      field: "media_name",
      headerName: "Название",
      flex: 1,
    },
    {
      field: "media_type",
      headerName: "Тип",
      width: 200,
      flex: 1,
      renderCell: (params: GridRenderCellParams) => {
        return (
          <p>
            {
              MEDIA_TYPE_LABELS[
                params.row.media_type as keyof typeof MEDIA_TYPE_LABELS
              ]
            }
          </p>
        );
      },
    },
    {
      field: "actions",
      headerName: "Действия",
      width: 200,
      align: "center",
      headerAlign: "center",

      renderCell: (params: GridRenderCellParams) => {
        return (
          <div className="flex h-full gap-7 justify-center items-center">
            <button onClick={() => navigate(`/media/${params.row.id}`)}>
              <Eye size={20} className="text-green-500" />
            </button>
            <button
              onClick={() => {
                setIsDeleteModalOpen(true);
                setRowId(params.row.id);
              }}
            >
              <Trash2 size={20} className="text-red-500" />
            </button>
          </div>
        );
      },
    },
  ];

  const rows = media.map((media) => ({
    id: media.id,
    media_name: media.media_name,
    media_type: media.media_type,
  }));

  return (
    <>
      <div className="w-full">
        <div className="flex justify-between items-center mb-10">
          <h1 className="text-2xl">Медиа</h1>
          <CreateButton label="Создать медиа" path="/media/create" />
        </div>
        <DataGrid
          rows={rows}
          columns={columns}
          hideFooterPagination
          hideFooter
        />
      </div>

      <DeleteModal
        open={isDeleteModalOpen}
        onDelete={async () => {
          if (rowId) {
            deleteMedia(rowId.toString());
            getMedia();
          }
          setIsDeleteModalOpen(false);
          setRowId(null);
        }}
        onCancel={() => {
          setIsDeleteModalOpen(false);
          setRowId(null);
        }}
      />
    </>
  );
});
